@@ -68,8 +68,8 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit=50, verbose=FALSE, Niter.max=500, t
     }
 
     if(verbose) {
-        cat("EM for beta mixture model.\n")
-        cat("Initial estimates:\n")
+        message("EM for beta mixture model.\n")
+        message("Initial estimates:\n")
         print(mixEst)
     }
 
@@ -182,7 +182,7 @@ EM_bmm_ab <- function(x, Nc, mix_init, Ninit=50, verbose=FALSE, Niter.max=500, t
         }
         if(is.na(eps.converged)) eps.converged <- 0
         if(verbose) {
-            cat("Iteration ", iter, ": log-likelihood = ", lliCur, "; Dlli = ", Dlli, "; converged = ", eps.converged, " / ", Npar, "\n", sep="")
+            message("Iteration ", iter, ": log-likelihood = ", lliCur, "; Dlli = ", Dlli, "; converged = ", eps.converged, " / ", Npar, "\n", sep="")
         }
         if(checkTol & Dlli < tol) {
             break
